from . import EnumType_pb2
from . import His_Quote_EnumType_pb2
from . import MsgType_pb2
from . import Quote_Message_pb2

EAccStatus = EnumType_pb2.EAccStatus
EAdjust = His_Quote_EnumType_pb2.EAdjust
EBusinessType = EnumType_pb2.EBusinessType
ECxRejReasonType = EnumType_pb2.ECxRejReasonType
EDepositRetCode = EnumType_pb2.EDepositRetCode
EExecType = EnumType_pb2.EExecType
EFundamentalsType = His_Quote_EnumType_pb2.EFundamentalsType
EHisQuoteErrCode = His_Quote_EnumType_pb2.EHisQuoteErrCode
EHisQuoteFrontMsgID = His_Quote_EnumType_pb2.EHisQuoteFrontMsgID
ELoginRetCode = EnumType_pb2.ELoginRetCode
EMarketDataType = Quote_Message_pb2.EMarketDataType
EMsgType = MsgType_pb2.EMsgType
EOrderRejectReason = EnumType_pb2.EOrderRejectReason
EOrderSide = EnumType_pb2.EOrderSide
EOrderStatus = EnumType_pb2.EOrderStatus
EOrderType = EnumType_pb2.EOrderType
EPeriod = His_Quote_EnumType_pb2.EPeriod
EPositionEffect = EnumType_pb2.EPositionEffect
EQuoteMsgID = Quote_Message_pb2.EQuoteMsgID
EQuoteRetCode = Quote_Message_pb2.EQuoteRetCode
ERegisterRet = EnumType_pb2.ERegisterRet
ESecurityType = Quote_Message_pb2.ESecurityType
ESessionStatus = EnumType_pb2.ESessionStatus
ETradeMsgID = EnumType_pb2.ETradeMsgID
KAccStatus_Disable = EnumType_pb2.KAccStatus_Disable
KAccStatus_Normal = EnumType_pb2.KAccStatus_Normal
KAccStatus_Unknown = EnumType_pb2.KAccStatus_Unknown
KAccStatus_WrittenOff = EnumType_pb2.KAccStatus_WrittenOff
KAdjust_NONE = His_Quote_EnumType_pb2.KAdjust_NONE
KAdjust_POST = His_Quote_EnumType_pb2.KAdjust_POST
KAdjust_PREV = His_Quote_EnumType_pb2.KAdjust_PREV
KBusinessType_NORMAL = EnumType_pb2.KBusinessType_NORMAL
KBusinessType_Unknown = EnumType_pb2.KBusinessType_Unknown
KCxRejReasonType_Broker = EnumType_pb2.KCxRejReasonType_Broker
KCxRejReasonType_Duplicate = EnumType_pb2.KCxRejReasonType_Duplicate
KCxRejReasonType_Other = EnumType_pb2.KCxRejReasonType_Other
KCxRejReasonType_PendingCancel = EnumType_pb2.KCxRejReasonType_PendingCancel
KCxRejReasonType_TooLateCancel = EnumType_pb2.KCxRejReasonType_TooLateCancel
KCxRejReasonType_UnknowOrder = EnumType_pb2.KCxRejReasonType_UnknowOrder
KDepositReCode_CapitalOverrun = EnumType_pb2.KDepositReCode_CapitalOverrun
KDepositReCode_IllegalAccount = EnumType_pb2.KDepositReCode_IllegalAccount
KDepositReCode_IllegalPara = EnumType_pb2.KDepositReCode_IllegalPara
KDepositReCode_NoEnoughCash = EnumType_pb2.KDepositReCode_NoEnoughCash
KDepositReCode_NoError = EnumType_pb2.KDepositReCode_NoError
KDepositReCode_Unknown = EnumType_pb2.KDepositReCode_Unknown
KExecType_Calculated = EnumType_pb2.KExecType_Calculated
KExecType_Canceled = EnumType_pb2.KExecType_Canceled
KExecType_DoneForDay = EnumType_pb2.KExecType_DoneForDay
KExecType_Expired = EnumType_pb2.KExecType_Expired
KExecType_New = EnumType_pb2.KExecType_New
KExecType_OrderStatus = EnumType_pb2.KExecType_OrderStatus
KExecType_PendingCancel = EnumType_pb2.KExecType_PendingCancel
KExecType_PendingNew = EnumType_pb2.KExecType_PendingNew
KExecType_PendingReplace = EnumType_pb2.KExecType_PendingReplace
KExecType_Rejected = EnumType_pb2.KExecType_Rejected
KExecType_Replaced = EnumType_pb2.KExecType_Replaced
KExecType_Restated = EnumType_pb2.KExecType_Restated
KExecType_Stopped = EnumType_pb2.KExecType_Stopped
KExecType_Suspended = EnumType_pb2.KExecType_Suspended
KExecType_Trade = EnumType_pb2.KExecType_Trade
KExecType_TradeCancel = EnumType_pb2.KExecType_TradeCancel
KExecType_TradeCorrect = EnumType_pb2.KExecType_TradeCorrect
KExecType_Unknown = EnumType_pb2.KExecType_Unknown
KFundamentalsType_BalanceSheet = His_Quote_EnumType_pb2.KFundamentalsType_BalanceSheet
KFundamentalsType_Cashflow = His_Quote_EnumType_pb2.KFundamentalsType_Cashflow
KFundamentalsType_Deriv = His_Quote_EnumType_pb2.KFundamentalsType_Deriv
KFundamentalsType_Income = His_Quote_EnumType_pb2.KFundamentalsType_Income
KFundamentalsType_Prim = His_Quote_EnumType_pb2.KFundamentalsType_Prim
KFundamentalsType_TradingDerivative = His_Quote_EnumType_pb2.KFundamentalsType_TradingDerivative
KFundamentalsType_Unknown = His_Quote_EnumType_pb2.KFundamentalsType_Unknown
KHisFrontMsgID_GetCalendarReq = His_Quote_EnumType_pb2.KHisFrontMsgID_GetCalendarReq
KHisFrontMsgID_GetCalendarRsp = His_Quote_EnumType_pb2.KHisFrontMsgID_GetCalendarRsp
KHisFrontMsgID_GetFundamentalsNumReq = His_Quote_EnumType_pb2.KHisFrontMsgID_GetFundamentalsNumReq
KHisFrontMsgID_GetFundamentalsNumRsp = His_Quote_EnumType_pb2.KHisFrontMsgID_GetFundamentalsNumRsp
KHisFrontMsgID_GetFundamentalsReq = His_Quote_EnumType_pb2.KHisFrontMsgID_GetFundamentalsReq
KHisFrontMsgID_GetFundamentalsRsp = His_Quote_EnumType_pb2.KHisFrontMsgID_GetFundamentalsRsp
KHisFrontMsgID_GetNextTradingDateReq = His_Quote_EnumType_pb2.KHisFrontMsgID_GetNextTradingDateReq
KHisFrontMsgID_GetNextTradingDateRsp = His_Quote_EnumType_pb2.KHisFrontMsgID_GetNextTradingDateRsp
KHisFrontMsgID_GetPreviousTradingDateReq = His_Quote_EnumType_pb2.KHisFrontMsgID_GetPreviousTradingDateReq
KHisFrontMsgID_GetPreviousTradingDateRsp = His_Quote_EnumType_pb2.KHisFrontMsgID_GetPreviousTradingDateRsp
KHisFrontMsgID_LoginReq = His_Quote_EnumType_pb2.KHisFrontMsgID_LoginReq
KHisFrontMsgID_LoginRsp = His_Quote_EnumType_pb2.KHisFrontMsgID_LoginRsp
KHisFrontMsgID_LogoutReq = His_Quote_EnumType_pb2.KHisFrontMsgID_LogoutReq
KHisFrontMsgID_QueryHisBarsNumReq = His_Quote_EnumType_pb2.KHisFrontMsgID_QueryHisBarsNumReq
KHisFrontMsgID_QueryHisBarsNumRsp = His_Quote_EnumType_pb2.KHisFrontMsgID_QueryHisBarsNumRsp
KHisFrontMsgID_QueryHisBarsReq = His_Quote_EnumType_pb2.KHisFrontMsgID_QueryHisBarsReq
KHisFrontMsgID_QueryHisBarsRsp = His_Quote_EnumType_pb2.KHisFrontMsgID_QueryHisBarsRsp
KHisFrontMsgID_QueryHisTicksNumReq = His_Quote_EnumType_pb2.KHisFrontMsgID_QueryHisTicksNumReq
KHisFrontMsgID_QueryHisTicksNumRsp = His_Quote_EnumType_pb2.KHisFrontMsgID_QueryHisTicksNumRsp
KHisFrontMsgID_QueryHisTicksReq = His_Quote_EnumType_pb2.KHisFrontMsgID_QueryHisTicksReq
KHisFrontMsgID_QueryHisTicksRsp = His_Quote_EnumType_pb2.KHisFrontMsgID_QueryHisTicksRsp
KHisFrontMsgID_Unknown = His_Quote_EnumType_pb2.KHisFrontMsgID_Unknown
KHisQuoteErrCode_DoNotLogin = His_Quote_EnumType_pb2.KHisQuoteErrCode_DoNotLogin
KHisQuoteErrCode_ErrStaffLoginPasswd = His_Quote_EnumType_pb2.KHisQuoteErrCode_ErrStaffLoginPasswd
KHisQuoteErrCode_ErrStaffLoginSkey = His_Quote_EnumType_pb2.KHisQuoteErrCode_ErrStaffLoginSkey
KHisQuoteErrCode_LoginSucc = His_Quote_EnumType_pb2.KHisQuoteErrCode_LoginSucc
KHisQuoteErrCode_NoPrivilegeAdmin = His_Quote_EnumType_pb2.KHisQuoteErrCode_NoPrivilegeAdmin
KHisQuoteErrCode_NotTradeDay = His_Quote_EnumType_pb2.KHisQuoteErrCode_NotTradeDay
KHisQuoteErrCode_NotTradeTime = His_Quote_EnumType_pb2.KHisQuoteErrCode_NotTradeTime
KHisQuoteErrCode_ReqTypeUnknown = His_Quote_EnumType_pb2.KHisQuoteErrCode_ReqTypeUnknown
KHisQuoteErrCode_StaffAccountForbidden = His_Quote_EnumType_pb2.KHisQuoteErrCode_StaffAccountForbidden
KHisQuoteErrCode_StaffLogOutFailed = His_Quote_EnumType_pb2.KHisQuoteErrCode_StaffLogOutFailed
KHisQuoteErrCode_StaffNotExist = His_Quote_EnumType_pb2.KHisQuoteErrCode_StaffNotExist
KHisQuoteErrCode_SystemError = His_Quote_EnumType_pb2.KHisQuoteErrCode_SystemError
KHisQuoteErrCode_Unknown = His_Quote_EnumType_pb2.KHisQuoteErrCode_Unknown
KLoginReCode_AccUnNormal = EnumType_pb2.KLoginReCode_AccUnNormal
KLoginReCode_LoginSucc = EnumType_pb2.KLoginReCode_LoginSucc
KLoginReCode_Unknown = EnumType_pb2.KLoginReCode_Unknown
KLoginReCode_UnknownAcc = EnumType_pb2.KLoginReCode_UnknownAcc
KMarketDataType_Actual = Quote_Message_pb2.KMarketDataType_Actual
KMarketDataType_Future = Quote_Message_pb2.KMarketDataType_Future
KMarketDataType_SOption = Quote_Message_pb2.KMarketDataType_SOption
KMarketDataType_Unknown = Quote_Message_pb2.KMarketDataType_Unknown
KMsgType_Exchange_Req = MsgType_pb2.KMsgType_Exchange_Req
KMsgType_Exchange_Rsp = MsgType_pb2.KMsgType_Exchange_Rsp
KMsgType_FrontQuote = MsgType_pb2.KMsgType_FrontQuote
KMsgType_FrontQuoteInner = MsgType_pb2.KMsgType_FrontQuoteInner
KMsgType_Net = MsgType_pb2.KMsgType_Net
KMsgType_Quote = MsgType_pb2.KMsgType_Quote
KMsgType_Strategy = MsgType_pb2.KMsgType_Strategy
KMsgType_Unknown = MsgType_pb2.KMsgType_Unknown
KOrdRejReason_DuplicateOrd = EnumType_pb2.KOrdRejReason_DuplicateOrd
KOrdRejReason_ExchangeClosed = EnumType_pb2.KOrdRejReason_ExchangeClosed
KOrdRejReason_IllegalEntrustedBusiness = EnumType_pb2.KOrdRejReason_IllegalEntrustedBusiness
KOrdRejReason_IncorrectQty = EnumType_pb2.KOrdRejReason_IncorrectQty
KOrdRejReason_InvalidAcc = EnumType_pb2.KOrdRejReason_InvalidAcc
KOrdRejReason_InvalidBusinessCategory = EnumType_pb2.KOrdRejReason_InvalidBusinessCategory
KOrdRejReason_LackDeposit = EnumType_pb2.KOrdRejReason_LackDeposit
KOrdRejReason_NonTradingTime = EnumType_pb2.KOrdRejReason_NonTradingTime
KOrdRejReason_NotEnoughPosition = EnumType_pb2.KOrdRejReason_NotEnoughPosition
KOrdRejReason_OrdExceedsLimit = EnumType_pb2.KOrdRejReason_OrdExceedsLimit
KOrdRejReason_PriceError = EnumType_pb2.KOrdRejReason_PriceError
KOrdRejReason_PriceNonMultipleTick = EnumType_pb2.KOrdRejReason_PriceNonMultipleTick
KOrdRejReason_PriceZero = EnumType_pb2.KOrdRejReason_PriceZero
KOrdRejReason_QtyNonMultipleBuyUnit = EnumType_pb2.KOrdRejReason_QtyNonMultipleBuyUnit
KOrdRejReason_SecuritiesTrading = EnumType_pb2.KOrdRejReason_SecuritiesTrading
KOrdRejReason_StaleOrd = EnumType_pb2.KOrdRejReason_StaleOrd
KOrdRejReason_TooLateEnter = EnumType_pb2.KOrdRejReason_TooLateEnter
KOrdRejReason_UnknowOrd = EnumType_pb2.KOrdRejReason_UnknowOrd
KOrdRejReason_UnknownAcc = EnumType_pb2.KOrdRejReason_UnknownAcc
KOrdRejReason_UnknownSymbol = EnumType_pb2.KOrdRejReason_UnknownSymbol
KOrdRejReason_UnsupportedOrdChara = EnumType_pb2.KOrdRejReason_UnsupportedOrdChara
KOrderDirection_Buy = EnumType_pb2.KOrderDirection_Buy
KOrderDirection_Call = EnumType_pb2.KOrderDirection_Call
KOrderDirection_Callable = EnumType_pb2.KOrderDirection_Callable
KOrderDirection_FinancingToBuy = EnumType_pb2.KOrderDirection_FinancingToBuy
KOrderDirection_FinancingToSell = EnumType_pb2.KOrderDirection_FinancingToSell
KOrderDirection_Sell = EnumType_pb2.KOrderDirection_Sell
KOrderDirection_Unknown = EnumType_pb2.KOrderDirection_Unknown
KOrderRejectReason_NoError = EnumType_pb2.KOrderRejectReason_NoError
KOrderStatus_AcceptedForBidding = EnumType_pb2.KOrderStatus_AcceptedForBidding
KOrderStatus_Calculated = EnumType_pb2.KOrderStatus_Calculated
KOrderStatus_Canceled = EnumType_pb2.KOrderStatus_Canceled
KOrderStatus_DoneForDay = EnumType_pb2.KOrderStatus_DoneForDay
KOrderStatus_Expired = EnumType_pb2.KOrderStatus_Expired
KOrderStatus_Filled = EnumType_pb2.KOrderStatus_Filled
KOrderStatus_New = EnumType_pb2.KOrderStatus_New
KOrderStatus_PartiallyFilled = EnumType_pb2.KOrderStatus_PartiallyFilled
KOrderStatus_PendingCancel = EnumType_pb2.KOrderStatus_PendingCancel
KOrderStatus_PendingNew = EnumType_pb2.KOrderStatus_PendingNew
KOrderStatus_PendingReplace = EnumType_pb2.KOrderStatus_PendingReplace
KOrderStatus_Rejected = EnumType_pb2.KOrderStatus_Rejected
KOrderStatus_Stopped = EnumType_pb2.KOrderStatus_Stopped
KOrderStatus_Suspended = EnumType_pb2.KOrderStatus_Suspended
KOrderStatus_Unknown = EnumType_pb2.KOrderStatus_Unknown
KOrderType_All_Or_Cancel = EnumType_pb2.KOrderType_All_Or_Cancel
KOrderType_Best_5_Then_Cancel = EnumType_pb2.KOrderType_Best_5_Then_Cancel
KOrderType_Best_5_Then_Limit = EnumType_pb2.KOrderType_Best_5_Then_Limit
KOrderType_Best_Of_Conterparty = EnumType_pb2.KOrderType_Best_Of_Conterparty
KOrderType_Best_Of_Party = EnumType_pb2.KOrderType_Best_Of_Party
KOrderType_Immediately_Or_Cancel = EnumType_pb2.KOrderType_Immediately_Or_Cancel
KOrderType_Limit = EnumType_pb2.KOrderType_Limit
KOrderType_Market = EnumType_pb2.KOrderType_Market
KOrderType_Market_Then_Limit = EnumType_pb2.KOrderType_Market_Then_Limit
KOrderType_Stop = EnumType_pb2.KOrderType_Stop
KOrderType_Unknown = EnumType_pb2.KOrderType_Unknown
KPeriod_DAILY = His_Quote_EnumType_pb2.KPeriod_DAILY
KPeriod_FIFTEEN_NMIN = His_Quote_EnumType_pb2.KPeriod_FIFTEEN_NMIN
KPeriod_FIVE_MIN = His_Quote_EnumType_pb2.KPeriod_FIVE_MIN
KPeriod_HALF_HOUR = His_Quote_EnumType_pb2.KPeriod_HALF_HOUR
KPeriod_ONE_HOUR = His_Quote_EnumType_pb2.KPeriod_ONE_HOUR
KPeriod_ONE_MIN = His_Quote_EnumType_pb2.KPeriod_ONE_MIN
KPeriod_Unknown = His_Quote_EnumType_pb2.KPeriod_Unknown
KPositionEffect_Close = EnumType_pb2.KPositionEffect_Close
KPositionEffect_CloseToday = EnumType_pb2.KPositionEffect_CloseToday
KPositionEffect_CloseYesterday = EnumType_pb2.KPositionEffect_CloseYesterday
KPositionEffect_ForceClose = EnumType_pb2.KPositionEffect_ForceClose
KPositionEffect_Open = EnumType_pb2.KPositionEffect_Open
KPositionEffect_Unknown = EnumType_pb2.KPositionEffect_Unknown
KQueryHistoryOrdersAck = EnumType_pb2.KQueryHistoryOrdersAck
KQueryHistoryOrdersReq = EnumType_pb2.KQueryHistoryOrdersReq
KQueryHistoryTradesAck = EnumType_pb2.KQueryHistoryTradesAck
KQueryHistoryTradesReq = EnumType_pb2.KQueryHistoryTradesReq
KQueryOrdersAck = EnumType_pb2.KQueryOrdersAck
KQueryOrdersReq = EnumType_pb2.KQueryOrdersReq
KQueryPositionsAck = EnumType_pb2.KQueryPositionsAck
KQueryPositionsReq = EnumType_pb2.KQueryPositionsReq
KQueryHisPositionsAck = EnumType_pb2.KQueryHisPositionsAck
KQueryHisPositionsReq = EnumType_pb2.KQueryHisPositionsReq
KQueryTradesAck = EnumType_pb2.KQueryTradesAck
KQueryTradesReq = EnumType_pb2.KQueryTradesReq
KQuoteMsgID_QuerySecurityInfoReq = Quote_Message_pb2.KQuoteMsgID_QuerySecurityInfoReq
KQuoteMsgID_QuerySecurityInfoRsp = Quote_Message_pb2.KQuoteMsgID_QuerySecurityInfoRsp
KQuoteMsgID_QuoteQuery = Quote_Message_pb2.KQuoteMsgID_QuoteQuery
KQuoteMsgID_QuoteQueryAck = Quote_Message_pb2.KQuoteMsgID_QuoteQueryAck
KQuoteMsgID_QuoteSnapshot = Quote_Message_pb2.KQuoteMsgID_QuoteSnapshot
KQuoteMsgID_Subscribe = Quote_Message_pb2.KQuoteMsgID_Subscribe
KQuoteMsgID_SubscribeAck = Quote_Message_pb2.KQuoteMsgID_SubscribeAck
KQuoteMsgID_TimeStamp = Quote_Message_pb2.KQuoteMsgID_TimeStamp
KQuoteMsgID_UnSubscribe = Quote_Message_pb2.KQuoteMsgID_UnSubscribe
KQuoteMsgID_UnSubscribeAck = Quote_Message_pb2.KQuoteMsgID_UnSubscribeAck
KQuoteMsgID_Unknown = Quote_Message_pb2.KQuoteMsgID_Unknown
KQuoteRetCode_HasError = Quote_Message_pb2.KQuoteRetCode_HasError
KQuoteRetCode_Sucess = Quote_Message_pb2.KQuoteRetCode_Sucess
KQuoteRetCode_Unknown = Quote_Message_pb2.KQuoteRetCode_Unknown
KRegisterRet_InvalidStrategy = EnumType_pb2.KRegisterRet_InvalidStrategy
KRegisterRet_ReRegister = EnumType_pb2.KRegisterRet_ReRegister
KRegisterRet_Success = EnumType_pb2.KRegisterRet_Success
KRegisterRet_Unknown = EnumType_pb2.KRegisterRet_Unknown
KSecurityType_Bond = Quote_Message_pb2.KSecurityType_Bond
KSecurityType_Fund = Quote_Message_pb2.KSecurityType_Fund
KSecurityType_Future = Quote_Message_pb2.KSecurityType_Future
KSecurityType_FutureOption = Quote_Message_pb2.KSecurityType_FutureOption
KSecurityType_Index = Quote_Message_pb2.KSecurityType_Index
KSecurityType_IndexFuture = Quote_Message_pb2.KSecurityType_IndexFuture
KSecurityType_Option = Quote_Message_pb2.KSecurityType_Option
KSecurityType_Stock = Quote_Message_pb2.KSecurityType_Stock
KSecurityType_Unknown = Quote_Message_pb2.KSecurityType_Unknown
KSessionStatus_Closed = EnumType_pb2.KSessionStatus_Closed
KSessionStatus_Connected = EnumType_pb2.KSessionStatus_Connected
KSessionStatus_Disconnected = EnumType_pb2.KSessionStatus_Disconnected
KSessionStatus_UnKnown = EnumType_pb2.KSessionStatus_UnKnown
KTradeReqType_AccDepositAck = EnumType_pb2.KTradeReqType_AccDepositAck
KTradeReqType_AccDepositReq = EnumType_pb2.KTradeReqType_AccDepositReq
KTradeReqType_CancelOrder = EnumType_pb2.KTradeReqType_CancelOrder
KTradeReqType_ExecReport = EnumType_pb2.KTradeReqType_ExecReport
KTradeReqType_PlaceOrder = EnumType_pb2.KTradeReqType_PlaceOrder
KTradeReqType_QryHisAccAck = EnumType_pb2.KTradeReqType_QryHisAccAck
KTradeReqType_QryHisAccReq = EnumType_pb2.KTradeReqType_QryHisAccReq
KTradeReqType_QryHisDepositAck = EnumType_pb2.KTradeReqType_QryHisDepositAck
KTradeReqType_QryHisDepositReq = EnumType_pb2.KTradeReqType_QryHisDepositReq
KTradeReqType_QrySecurityStaticAck = EnumType_pb2.KTradeReqType_QrySecurityStaticAck
KTradeReqType_QrySecurityStaticReq = EnumType_pb2.KTradeReqType_QrySecurityStaticReq
KTradeReqType_RejectCancelReport = EnumType_pb2.KTradeReqType_RejectCancelReport
KTradeReqType_TradingAccQryAck = EnumType_pb2.KTradeReqType_TradingAccQryAck
KTradeReqType_TradingAccQryReq = EnumType_pb2.KTradeReqType_TradingAccQryReq
KTradeReqType_Unknown = EnumType_pb2.KTradeReqType_Unknown
KTradeRspType_OrdStatusReport = EnumType_pb2.KTradeRspType_OrdStatusReport
KVexchangeMsgID_HeartBeatAck = EnumType_pb2.KVexchangeMsgID_HeartBeatAck
KVexchangeMsgID_HeartBeatReq = EnumType_pb2.KVexchangeMsgID_HeartBeatReq
KVexchangeMsgID_LoginAck = EnumType_pb2.KVexchangeMsgID_LoginAck
KVexchangeMsgID_LoginReq = EnumType_pb2.KVexchangeMsgID_LoginReq
KVexchangeMsgID_LogoutReq = EnumType_pb2.KVexchangeMsgID_LogoutReq
KVexchangeMsgID_RegisterAck = EnumType_pb2.KVexchangeMsgID_RegisterAck
KVexchangeMsgID_RegisterReq = EnumType_pb2.KVexchangeMsgID_RegisterReq
KVexchangeMsgID_SessionControl = EnumType_pb2.KVexchangeMsgID_SessionControl
KVexchangeMsgID_UnRegisterAck = EnumType_pb2.KVexchangeMsgID_UnRegisterAck
KVexchangeMsgID_UnRegisterReq = EnumType_pb2.KVexchangeMsgID_UnRegisterReq
KVexchangeMsgID_UserInfoQryAck = EnumType_pb2.KVexchangeMsgID_UserInfoQryAck
KVexchangeMsgID_UserInfoQryReq = EnumType_pb2.KVexchangeMsgID_UserInfoQryReq
